@@ -74,7 +74,11 @@ class S3Storage(Storage):
                 return None
 
         binary = entity.cw_edited.pop(attr)
-        if binary is not None:
+        if binary is None:
+            # remove S3 key
+            entity.cw_edited.edited_attribute(attr, None)
+            self.entity_deleted(entity, attr)
+        else:
             key = self.get_s3_key(entity, attr)
             if key is None:
                 key = self.new_s3_key(entity, attr)
